#Topsis-Anant-102083043
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-Anant-102083043```

##Sample Use case
import topsis-Anant-102083043 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")
